@@ -2,9 +2,9 @@ package Test::Class::Moose;
 
 # ABSTRACT: Serious testing for serious Perl
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Moose 2.0000;
 use Carp;
@@ -255,7 +255,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
