@@ -2,9 +2,9 @@ package Test::Class::Moose::Report;
 
 # ABSTRACT: Test information for Test::Class::Moose
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Carp;
 use Moose;
@@ -138,7 +138,7 @@ Test::Class::Moose::Report - Test information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
