@@ -2,9 +2,9 @@ package Test::Class::Moose::Report::Class;
 
 # ABSTRACT: Reporting on test classes
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Moose;
 use Carp;
@@ -47,7 +47,7 @@ Test::Class::Moose::Report::Class - Reporting on test classes
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 DESCRIPTION
 
