@@ -2,9 +2,9 @@ package Test::Class::Moose::Report::Time;
 
 # ABSTRACT: Reporting object for timing
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Moose;
 use Benchmark qw(timestr :hireswallclock);
@@ -57,7 +57,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 DESCRIPTION
 
