@@ -2,9 +2,9 @@ package Test::Class::Moose::Role::Executor;
 
 # ABSTRACT: Common code for Runner classes
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Moose::Role 2.0000;
 use Carp;
@@ -532,7 +532,7 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 DESCRIPTION
 
