@@ -2,9 +2,9 @@ package Test::Class::Moose::Runner;
 
 # ABSTRACT: Runner for Test::Class::Moose tests
 
-use 5.10.0;
+use 5.010000;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use Moose 2.0000;
 use Carp;
@@ -109,7 +109,7 @@ Test::Class::Moose::Runner - Runner for Test::Class::Moose tests
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
